==> devextreme-21.1.1-alpha-21089-0329.tgz: package/cjs/renovation/ui/scheduler/workspaces/base/date_table/layout.j.js <==
/**
 * DevExtreme (cjs/renovation/ui/scheduler/workspaces/base/date_table/layout.j.js)
 * Version: 21.1.0 (build 21089-0329)
 * Build date: Tue Mar 30 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../../../../component_wrapper/component"));
var _layout = require("./layout");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DateTableLayoutBase = function(_BaseComponent) {
    _inheritsLoose(DateTableLayoutBase, _BaseComponent);

    function DateTableLayoutBase() {
        return _BaseComponent.apply(this, arguments) || this
    }
    var _proto = DateTableLayoutBase.prototype;
    _proto.getProps = function() {
        var props = _BaseComponent.prototype.getProps.call(this);
        props.cellTemplate = this._createTemplateComponent(props, props.cellTemplate);
        props.dataCellTemplate = this._createTemplateComponent(props, props.dataCellTemplate);
        return props
    };
    _createClass(DateTableLayoutBase, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: ["cellTemplate", "dataCellTemplate"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _layout.DateTableLayoutBase
        }
    }]);
    return DateTableLayoutBase
}(_component.default);
exports.default = DateTableLayoutBase;
(0, _component_registrator.default)("dxDateTableLayoutBase", DateTableLayoutBase);
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-21.2.1-alpha-21243-0310.tgz: package/cjs/renovation/ui/scheduler/workspaces/base/date_table/layout.j.js <==
/**
 * DevExtreme (cjs/renovation/ui/scheduler/workspaces/base/date_table/layout.j.js)
 * Version: 21.2.0 (build 21243-0310)
 * Build date: Tue Aug 31 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../../../../component_wrapper/common/component"));
var _layout = require("./layout");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DateTableLayoutBase = function(_BaseComponent) {
    _inheritsLoose(DateTableLayoutBase, _BaseComponent);

    function DateTableLayoutBase() {
        return _BaseComponent.apply(this, arguments) || this
    }
    _createClass(DateTableLayoutBase, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: ["cellTemplate", "dataCellTemplate"],
                props: ["cellTemplate", "viewData", "groupOrientation", "leftVirtualCellWidth", "rightVirtualCellWidth", "topVirtualRowHeight", "bottomVirtualRowHeight", "addDateTableClass", "dataCellTemplate"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _layout.DateTableLayoutBase
        }
    }]);
    return DateTableLayoutBase
}(_component.default);
exports.default = DateTableLayoutBase;
(0, _component_registrator.default)("dxDateTableLayoutBase", DateTableLayoutBase);
module.exports = exports.default;
module.exports.default = exports.default;
